@@ -145,7 +145,7 @@ t.result <- .C( "PointRectCov", as.double(pxcoord), as.double(pycoord), as.doubl
 	    result = double( npoints * npixel), abserr = as.double(1), as.integer(limit),
 	    as.integer(lenw + 1), as.integer(lenw), as.integer(lenw +1), as.integer(limit+1),
 	    integer(limit+1), double(lenw+1),  as.double(covpar), as.integer(n.mod),
-	    as.integer(n.mod.param), DUP = FALSE, NAOK=F, PACKAGE = thispackage
+	    as.integer(n.mod.param), DUP = TRUE, NAOK=F, PACKAGE = thispackage
         )
         return( t.result)
 } # end of function
