@@ -6,6 +6,10 @@ f.preCKrige.check.and.test <- function(newdata, neighbours, model, pwidth, pheig
 
     t.newdata.class <- class( newdata )
 
+    ### in order to use the Function CovairanceFct of the package RandomFields
+    RFoldstyle()
+
+
     if( t.newdata.class =="SpatialPolygons" || t.newdata.class == "SpatialPolygonsDataFrame" )
     {
 	#in no neighbours are defined
